==> zio-aws-ecs_2.13-5.17.104.8-sources.jar: zio/aws/ecs/model/UpdateClusterResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateClusterResponse(
    cluster: Option[zio.aws.ecs.model.Cluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.UpdateClusterResponse = {
    import UpdateClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.UpdateClusterResponse.ReadOnly =
    zio.aws.ecs.model.UpdateClusterResponse.wrap(buildAwsValue())
}
object UpdateClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.UpdateClusterResponse = zio.aws.ecs.model
      .UpdateClusterResponse(cluster.map(value => value.asEditable))
    def cluster: Option[zio.aws.ecs.model.Cluster.ReadOnly]
    def getCluster: ZIO[Any, AwsError, zio.aws.ecs.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
  ) extends zio.aws.ecs.model.UpdateClusterResponse.ReadOnly {
    override val cluster: Option[zio.aws.ecs.model.Cluster.ReadOnly] = scala
      .Option(impl.cluster())
      .map(value => zio.aws.ecs.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
  ): zio.aws.ecs.model.UpdateClusterResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ecs_2.13-5.17.176.1-sources.jar: zio/aws/ecs/model/UpdateClusterResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateClusterResponse(
    cluster: Optional[zio.aws.ecs.model.Cluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.UpdateClusterResponse = {
    import UpdateClusterResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.UpdateClusterResponse.ReadOnly =
    zio.aws.ecs.model.UpdateClusterResponse.wrap(buildAwsValue())
}
object UpdateClusterResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.UpdateClusterResponse = zio.aws.ecs.model
      .UpdateClusterResponse(cluster.map(value => value.asEditable))
    def cluster: Optional[zio.aws.ecs.model.Cluster.ReadOnly]
    def getCluster: ZIO[Any, AwsError, zio.aws.ecs.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
  ) extends zio.aws.ecs.model.UpdateClusterResponse.ReadOnly {
    override val cluster: Optional[zio.aws.ecs.model.Cluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cluster())
        .map(value => zio.aws.ecs.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.UpdateClusterResponse
  ): zio.aws.ecs.model.UpdateClusterResponse.ReadOnly = new Wrapper(impl)
}
